@@ -78,6 +78,8 @@ async def on_ready():
 @client.event
 async def on_message(message):
 
+    link_given = False
+
     on_message.triggering_message = message
 
     global triggering_message
@@ -241,13 +243,11 @@ async def on_message(message):
                     channel_to_connnect_to = message.author.voice.channel
                     voice_object = await channel_to_connnect_to.connect()
                     if command_dict[c]["source_to_play"] == None:
-                        try:
-                            if link_given != True:
-                                print(
-                                    "Bot will not play audio because no source file was given.")
-                                return
-                        except UnboundLocalError:
-                            pass
+                        if link_given != True:
+                            print(
+                                "Bot will not play audio because no source file was given.")
+                            return
+                        
                     command_dict[c]["source_to_play"] = f"{dir_path}/{song_name}.mp3"
 
                     file_to_play = FFmpegPCMAudio(
